==> bitsensor-node-js-core-1.1.0.tgz: package/test/hook/sequelize_test.js <==
const expect = require('chai').expect;
require('../../core/init');

const requireHook = require('require-in-the-middle');
requireHook(['sequelize', 'sequelize1'], function (exports, name) {

  return require('../../hook/sequelize')(exports, name)
});

const Sequelize = require('sequelize');
const Sequelize1 = require('sequelize1');

describe('Hook', function () {
  describe('Sequelize version 4', function () {
    let sequelize;
    let User;

    before(() => {
      sequelize = new Sequelize('database', 'username', 'password', {
        host: 'localhost',
        dialect: 'sqlite',
        logging: false
      });
      User = sequelize.define('user', {
        username: Sequelize.STRING,
        birthday: Sequelize.DATE
      });
      sequelize.sync()
        .then(() => User.create({
          username: 'janedoe',
          birthday: new Date(1980, 6, 20)
        }));
    });

    it('must contain sql invocation', function (done) {
      bitSensor.runSession(function () {
        bitSensor.traceIncrement();

        expect(bitSensor.getDatapoint().errors).to.be.empty;

        sequelize.sync()
          .then(() => User.findAll())
          .then(() => {
            expect(bitSensor.getDatapoint().invocation.sqlInvocations).to.have.lengthOf.at.least(1);
            done();
          });
      });
    });
  });

  describe('Sequelize version 1', function () {
    let sequelize;
    let User;

    before(() => {
      sequelize = new Sequelize1('database', 'username', 'password', {
        host: 'localhost',
        dialect: 'sqlite',
        logging: false
      });
      User = sequelize.define('User', {
        username: Sequelize1.STRING,
        birthday: Sequelize1.DATE
      })
      sequelize.sync()
        .success(() => User.create({
          username: 'janedoe',
          birthday: new Date(1980, 6, 20)
        }));
    })

    it('must contain sql invocation', function (done) {
      bitSensor.runSession(function () {
        bitSensor.traceIncrement();

        expect(bitSensor.getDatapoint().errors).to.be.empty;

        sequelize.sync()
          .success(() => User.findAll()
            .success(() => {
              expect(bitSensor.getDatapoint().invocation.sqlInvocations).to.have.lengthOf.at.least(1);
              done();
            }))
      });
    });
  });
});

==> bitsensor-node-js-core-2.0.7.tgz: package/test/hook/sequelize_test.js <==
const { expect } = require('chai');
require('../../core/init');
const requireHook = require('require-in-the-middle');

requireHook(['sequelize', 'sequelize1'], (exports, name) => {
  return require('../../hook/sequelize')(exports, name);
});

const Sequelize = require('sequelize');
const Sequelize1 = require('sequelize1');

describe('Hook', () => {
  describe('Sequelize version 4', () => {
    let sequelize;
    let User;

    before(() => {
      sequelize = new Sequelize('database', 'username', 'password', {
        host: 'localhost',
        dialect: 'sqlite',
        logging: false,
      });
      User = sequelize.define('user', {
        username: Sequelize.STRING,
        birthday: Sequelize.DATE,
      });
      sequelize.sync()
        .then(() => User.create({
          username: 'janedoe',
          birthday: new Date(1980, 6, 20),
        }));
    });

    it('must contain sql invocation', (done) => {
      bitSensor.runSession(() => {
        bitSensor.traceIncrement();

        expect(bitSensor.getDatapoint().errors).to.be.empty;

        sequelize.sync()
          .then(() => User.findAll())
          .then(() => {
            expect(bitSensor.getDatapoint().invocation.sqlInvocations).to.have.lengthOf.at.least(1);
            done();
          });
      });
    });
  });

  describe('Sequelize version 1', () => {
    let sequelize;
    let User;

    before(() => {
      sequelize = new Sequelize1('database', 'username', 'password', {
        host: 'localhost',
        dialect: 'sqlite',
        logging: false,
      });
      User = sequelize.define('User', {
        username: Sequelize1.STRING,
        birthday: Sequelize1.DATE,
      });
      sequelize.sync()
        .success(() => User.create({
          username: 'janedoe',
          birthday: new Date(1980, 6, 20),
        }));
    });

    it('must contain sql invocation', (done) => {
      bitSensor.runSession(() => {
        bitSensor.traceIncrement();

        expect(bitSensor.getDatapoint().errors).to.be.empty;

        sequelize.sync()
          .success(() => User.findAll()
            .success(() => {
              expect(bitSensor.getDatapoint().invocation.sqlInvocations).to.have.lengthOf.at.least(1);
              done();
            }));
      });
    });
  });
});
